#[repr(transparent)]pub struct Count(pub u32);Expand description
RTC counter register
Tuple Fields
0: u32Implementations
Sourceimpl Count
impl Count
Sourcepub const fn val(&self) -> u32
pub const fn val(&self) -> u32
A read reflects the current value of the main, 1 Hz RTC timer. A write loads a new initial value into the timer. The RTC counter will count up continuously at a 1 Hz rate once the RTC Software Reset is removed (by clearing bit 0 of the CTRL register). Only write to this register when the RTC_EN bit in the RTC CTRL Register is 0. The counter increments one second after the RTC_EN bit is set.
Sourcepub const fn set_val(&mut self, val: u32)
pub const fn set_val(&mut self, val: u32)
A read reflects the current value of the main, 1 Hz RTC timer. A write loads a new initial value into the timer. The RTC counter will count up continuously at a 1 Hz rate once the RTC Software Reset is removed (by clearing bit 0 of the CTRL register). Only write to this register when the RTC_EN bit in the RTC CTRL Register is 0. The counter increments one second after the RTC_EN bit is set.